This module implements a backend that uses a MOSEK OptServer instance for solving, for example solve.mosek.com:30080.
Structs
- Backend
- Simple model object that supports input of linear, conic and disjunctive constraints. It only stores data, it does not support solving or writing problems.
- Solver
Address